@@ -627,6 +627,16 @@ class Preferences : public QObject
          */
         void setShowHideShortcut( QKeySequence key_seq );
 
+        /**
+         * @brief getNewMessageFroms. Get the new message from list.
+         */
+        const QStringList& getNewMessageFroms() const;
+
+        /**
+         * @brief setNewMessageFroms. Set the new message from list.
+         */
+        void setNewMessageFroms( const QStringList& list );
+
         /**
          * @brief getKdeIntegrationOption. Get the KDE integration option.
          *
@@ -856,6 +866,11 @@ class Preferences : public QObject
          */
         void signalShowHideShortcutChange();
 
+        /**
+         * @brief signalNewMessageFromsChange. Signal the new message froms change.
+         */
+        void signalNewMessageFromsChange();
+
     private:
 
         /**
@@ -1077,6 +1092,11 @@ class Preferences : public QObject
          */
         QKeySequence m_show_hide_shortcut;
 
+        /**
+         * @brief m_new_message_froms. The new message froms list.
+         */
+        QStringList m_new_message_froms;
+
         /**
          * @brief m_kde_integration_option. KDE integration option.
          */
